@@ -1,7 +1,7 @@
 package App::CalendarDatesUtils;
 
 our $DATE = '2019-05-25'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -62,6 +62,12 @@ _
             summary => 'Use all installed Calendar::Dates::* modules',
             schema => 'true*',
         },
+        params => {
+            summary => 'Specify parameters',
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'param',
+            'schema' => ['hash*', of=>'str*'],
+        },
         detail => {
             schema => 'bool*',
             cmdline_aliases => {l=>{}},
@@ -105,7 +111,13 @@ sub list_calendar_dates {
 
         for my $y (@$years) {
             my $res;
-            eval { $res = $mod->get_entries($y, $mon, $day) };
+            eval {
+                my @args = ($y, $mon, $day);
+                if ($args{params} && keys %{$args{params}}) {
+                    unshift @args, $args{params};
+                }
+                $res = $mod->get_entries(@args);
+            };
             if ($@) {
                 warn "Can't get entries from $mod (year=$y): $@, skipped";
                 next;
@@ -136,7 +148,7 @@ App::CalendarDatesUtils - Utilities related to Calendar::Dates
 
 =head1 VERSION
 
-This document describes version 0.003 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-05-25.
+This document describes version 0.004 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-05-25.
 
 =head1 DESCRIPTION
 
@@ -183,6 +195,10 @@ List dates from all available years instead of a single year.
 
 =item * B<month> => I<int>
 
+=item * B<params> => I<hash>
+
+Specify parameters.
+
 =item * B<year> => I<int>
 
 Specify year of dates to list.
